Documentation
¶
Index ¶
- type Buffer
- func (cb *Buffer) Omit(n int) error
- func (cb *Buffer) Read(buf []byte) (int, error)
- func (cb *Buffer) ReadAvailability() int
- func (cb *Buffer) ReadByte() (byte, error)
- func (cb *Buffer) Reset()
- func (cb *Buffer) Size() int
- func (cb *Buffer) Write(buf []byte) (n int, err error)
- func (cb *Buffer) WriteAvailability() int
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Buffer ¶
type Buffer struct {
// contains filtered or unexported fields
}
Buffer implements a circular byte buffer, data is read from left to right but chucks are read from right to left. Unread data is never overwriten
func (*Buffer) ReadAvailability ¶
ReadAvailability returns the number of bytes that can be read
func (*Buffer) WriteAvailability ¶
WriteAvailability returns the number of bytes that can be writen without overwriting unread data
Click to show internal directories.
Click to hide internal directories.